@@ -91,7 +91,7 @@ class Hoe
   include Rake::DSL if defined?(Rake::DSL)
 
   # duh
-  VERSION = "3.14.2"
+  VERSION = "3.16.0"
 
   @@plugins = [:clean, :debug, :deps, :flay, :flog, :newb, :package,
                :publish, :gemcutter, :signing, :test]
@@ -413,7 +413,6 @@ class Hoe
     end
 
     initialize_plugins
-    activate_plugin_deps
   end
 
   ##
@@ -802,6 +801,7 @@ class Hoe
   # Finalize configuration
 
   def post_initialize
+    activate_plugin_deps
     intuit_values
     validate_fields
     define_spec
@@ -832,6 +832,48 @@ class Hoe
     spec_extras[:required_ruby_version] = versions
   end
 
+  ##
+  # Declare that this gem requires ruby to be in the 1.8+ family.
+
+  def ruby18!
+    require_ruby_version "~> 1.8"
+  end
+
+  ##
+  # Declare that this gem requires ruby to be in the 1.9 family.
+
+  def ruby19!
+    require_ruby_version "~> 1.9"
+  end
+
+  ##
+  # Declare that this gem requires ruby to be in the 2.0+ family.
+
+  def ruby20!
+    require_ruby_version "~> 2.0"
+  end
+
+  ##
+  # Declare that this gem requires ruby to be in the 2.1+ family.
+
+  def ruby21!
+    require_ruby_version "~> 2.1"
+  end
+
+  ##
+  # Declare that this gem requires ruby to be in the 2.2+ family.
+
+  def ruby22!
+    require_ruby_version "~> 2.2"
+  end
+
+  ##
+  # Declare that this gem requires ruby to be in the 2.3+ family.
+
+  def ruby23!
+    require_ruby_version "~> 2.3"
+  end
+
   ##
   # Provide a linear degrading value from n to m over start to finis
   # dates. If not provided, start and finis will default to 1/1 and
