@@ -24,8 +24,13 @@ module Hoe::Test
   #
   # eg FILTER="-n test_blah"
 
-  FILTER = ENV['FILTER'] || ENV['TESTOPTS'] || ""
-  FILTER << "-n #{ENV['N']}" if ENV['N']
+  FILTER = (ENV["FILTER"] || ENV["TESTOPTS"] || "").dup
+  FILTER << " -n #{ENV["N"]}" if ENV["N"]
+
+  # this is an unfortunate naming collision. I don't use the CPU (N)
+  # specifier so it is shifting to "C" inside of Hoe.
+  ENV.delete "N" if ENV["N"]
+  ENV["N"] = ENV["C"] if ENV["C"]
 
   ##
   # Optional: Array of incompatible versions for multiruby filtering.
@@ -60,7 +65,7 @@ module Hoe::Test
     self.multiruby_skip ||= []
     self.testlib        ||= :minitest
     self.test_prelude   ||= nil
-    self.rspec_dirs     ||= %w(spec lib)
+    self.rspec_dirs     ||= %w[spec lib]
     self.rspec_options  ||= []
   end
 
@@ -73,31 +78,43 @@ module Hoe::Test
     task :test
 
     if File.directory? "test" then
-      desc 'Run the test suite. Use FILTER or TESTOPTS to add flags/args.'
+      desc "Run the test suite. Use FILTER or TESTOPTS to add flags/args."
       task :test do
         ruby make_test_cmd
       end
 
-      desc 'Run the test suite using multiruby.'
+      desc "Print out the test command. Good for profiling and other tools."
+      task :test_cmd do
+        puts make_test_cmd
+      end
+
+      desc "Run the test suite using multiruby."
       task :multi do
         ENV["EXCLUDED_VERSIONS"] = multiruby_skip.join(":")
         system "multiruby -S rake"
       end
 
-      desc 'Show which test files fail when run alone.'
+      desc "Show which test files fail when run alone."
       task :test_deps do
         tests = Dir[*self.test_globs].uniq
 
-        paths = ['bin', 'lib', 'test'].join(File::PATH_SEPARATOR)
-        null_dev = Hoe::WINDOZE ? '> NUL 2>&1' : '> /dev/null 2>&1'
+        paths = %w[bin lib test].join(File::PATH_SEPARATOR)
+        null_dev = Hoe::WINDOZE ? "> NUL 2>&1" : "> /dev/null 2>&1"
 
         tests.each do |test|
-          if not system "ruby -I#{paths} #{test} #{null_dev}" then
+          unless system "ruby -I#{paths} #{test} #{null_dev}" then
             puts "Dependency Issues: #{test}"
           end
         end
       end
 
+      if testlib == :minitest then
+        desc "Show bottom 25 tests wrt time."
+        task "test:slow" do
+          sh "rake TESTOPTS=-v | sort -n -k2 -t= | tail -25"
+        end
+      end
+
       default_tasks << :test
     end
 
@@ -111,36 +128,13 @@ module Hoe::Test
       end
     end
 
-    desc 'Run the default task(s).'
+    desc "Run the default task(s)."
     task :default => default_tasks
 
-    unless default_tasks.empty? then
-      ##
-      # This is for Erik Hollensbe's rubygems-test project. Hoe is
-      # test-happy, so by using this plugin you're already testable. For
-      # more information, see: <https://github.com/erikh/rubygems-test>
-      # and/or <http://www.gem-testers.org/>
-
-      gemtest = ".gemtest"
-
-      gemtest.encode!(Encoding::UTF_8) if gemtest.respond_to?(:encoding)
-
-      self.spec.files += [gemtest]
-
-      pkg  = pkg_path
-      turd = "#{pkg}/.gemtest"
-
-      file turd => pkg_path do
-        touch turd
-      end
-
-      file "#{pkg}.gem" => turd
-    end
-
-    desc 'Run ZenTest against the package.'
+    desc "Run ZenTest against the package."
     task :audit do
-      libs = %w(lib test ext).join(File::PATH_SEPARATOR)
-      sh "zentest -I=#{libs} #{spec.files.grep(/^(lib|test)/).join(' ')}"
+      libs = %w[lib test ext].join(File::PATH_SEPARATOR)
+      sh "zentest -I=#{libs} #{spec.files.grep(/^(lib|test)/).join(" ")}"
     end
   end
 
@@ -148,7 +142,7 @@ module Hoe::Test
   # Generate the test command-line.
 
   def make_test_cmd
-    unless SUPPORTED_TEST_FRAMEWORKS.has_key?(testlib)
+    unless SUPPORTED_TEST_FRAMEWORKS.key?(testlib)
       raise "unsupported test framework #{testlib}"
     end
 
@@ -158,7 +152,7 @@ module Hoe::Test
     tests << framework if framework
     tests << test_globs.sort.map { |g| Dir.glob(g) }
     tests.flatten!
-    tests.map! {|f| %(require "#{f}")}
+    tests.map! { |f| %(require "#{f}") }
 
     tests.insert 1, test_prelude if test_prelude
 
@@ -169,7 +163,7 @@ module Hoe::Test
   # Attempt to load RSpec 2, returning true if successful
 
   def try_loading_rspec2
-    require 'rspec/core/rake_task'
+    require "rspec/core/rake_task"
 
     desc "Run all specifications"
     RSpec::Core::RakeTask.new(:spec) do |t|
@@ -188,7 +182,7 @@ module Hoe::Test
   # Attempt to load RSpec 1, returning true if successful
 
   def try_loading_rspec1
-    require 'spec/rake/spectask'
+    require "spec/rake/spectask"
 
     desc "Run all specifications"
     Spec::Rake::SpecTask.new(:spec) do |t|
